@@ -12,6 +12,7 @@
 # language governing permissions and limitations under the License.
 import copy
 import logging
+import re
 import threading
 
 from ibm_botocore.compat import six
@@ -164,6 +165,7 @@ class TransferManager(object):
         'ContentEncoding',
         'ContentLanguage',
         'ContentType',
+        'ExpectedBucketOwner',
         'Expires',
         'GrantFullControl',
         'GrantRead',
@@ -201,8 +203,18 @@ class TransferManager(object):
         'MFA',
         'VersionId',
         'RequestPayer',
+        'ExpectedBucketOwner'
     ]
 
+    VALIDATE_SUPPORTED_BUCKET_VALUES = True
+
+    _UNSUPPORTED_BUCKET_PATTERNS = {
+        'S3 Object Lambda': re.compile(
+            r'^arn:(aws).*:s3-object-lambda:[a-z\-0-9]+:[0-9]{12}:'
+            r'accesspoint[/:][a-zA-Z0-9\-]{1,63}'
+        ),
+    }
+
     def __init__(self, client, config=None, osutil=None, executor_cls=None):
         """A transfer manager interface for Amazon S3
 
@@ -306,6 +318,7 @@ class TransferManager(object):
         if subscribers is None:
             subscribers = []
         self._validate_all_known_args(extra_args, self.ALLOWED_UPLOAD_ARGS)
+        self._validate_if_bucket_supported(bucket)
         call_args = CallArgs(
             fileobj=fileobj, bucket=bucket, key=key, extra_args=extra_args,
             subscribers=subscribers
@@ -348,6 +361,7 @@ class TransferManager(object):
         if subscribers is None:
             subscribers = []
         self._validate_all_known_args(extra_args, self.ALLOWED_DOWNLOAD_ARGS)
+        self._validate_if_bucket_supported(bucket)
         call_args = CallArgs(
             bucket=bucket, key=key, fileobj=fileobj, extra_args=extra_args,
             subscribers=subscribers
@@ -401,6 +415,9 @@ class TransferManager(object):
         if source_client is None:
             source_client = self._client
         self._validate_all_known_args(extra_args, self.ALLOWED_COPY_ARGS)
+        if isinstance(copy_source, dict):
+            self._validate_if_bucket_supported(copy_source.get('Bucket'))
+        self._validate_if_bucket_supported(bucket)
         call_args = CallArgs(
             copy_source=copy_source, bucket=bucket, key=key,
             extra_args=extra_args, subscribers=subscribers,
@@ -435,12 +452,26 @@ class TransferManager(object):
         if subscribers is None:
             subscribers = []
         self._validate_all_known_args(extra_args, self.ALLOWED_DELETE_ARGS)
+        self._validate_if_bucket_supported(bucket)
         call_args = CallArgs(
             bucket=bucket, key=key, extra_args=extra_args,
             subscribers=subscribers
         )
         return self._submit_transfer(call_args, DeleteSubmissionTask)
 
+    def _validate_if_bucket_supported(self, bucket):
+        # s3 high level operations don't support some resources
+        # (eg. S3 Object Lambda) only direct API calls are available
+        # for such resources
+        if self.VALIDATE_SUPPORTED_BUCKET_VALUES:
+            for resource, pattern in self._UNSUPPORTED_BUCKET_PATTERNS.items():
+                match = pattern.match(bucket)
+                if match:
+                    raise ValueError(
+                        'TransferManager methods do not support %s '
+                        'resource. Use direct client calls instead.' % resource
+                    )
+
     def _validate_all_known_args(self, actual, allowed):
         for kwarg in actual:
             if kwarg not in allowed:
